Index: channels/sip/config_parser.c
===================================================================
--- channels/sip/config_parser.c	(revision 280705)
+++ channels/sip/config_parser.c	(working copy)
@@ -661,16 +661,18 @@
 	else
 		line = *hostname;
 
-	if ((port = strrchr(line, ':'))) {
-		*port++ = '\0';
+	if (ast_sockaddr_split_hostport(line, hostname, &port, 0) == 0) {
+		ast_log(LOG_WARNING, "Cannot parse host '%s' on line %d of sip.conf.\n",
+			line, lineno);
+		return -1;
+	}
 
+	if (port) {
 		if (!sscanf(port, "%5u", portnum)) {
 			ast_log(LOG_NOTICE, "'%s' is not a valid port number on line %d of sip.conf. using default.\n", port, lineno);
 			port = NULL;
 		}
-	}
-
-	if (!port) {
+	} else {
 		if (*transport & SIP_TRANSPORT_TLS) {
 			*portnum = STANDARD_TLS_PORT;
 		} else {
Index: include/asterisk/netsock2.h
===================================================================
--- include/asterisk/netsock2.h	(revision 280705)
+++ include/asterisk/netsock2.h	(working copy)
@@ -233,6 +233,26 @@
  * \since 1.8
  *
  * \brief
+ * Splits a string into its host and port components
+ *
+ * \param str[in]   The string to parse. May be modified by writing a NUL at the end of
+ *                  the host part.
+ * \param host[out] Pointer to the host component within \a str.
+ * \param port[out] Pointer to the port component within \a str.
+ * \param flags     If set to zero, a port MAY be present. If set to PARSE_PORT_IGNORE, a
+ *                  port MAY be present but will be ignored. If set to PARSE_PORT_REQUIRE,
+ *                  a port MUST be present. If set to PARSE_PORT_FORBID, a port MUST NOT
+ *                  be present.
+ *
+ * \retval 1 Success
+ * \retval 0 Failure
+ */
+int ast_sockaddr_split_hostport(char *str, char **host, char **port, int flags);
+
+/*!
+ * \since 1.8
+ *
+ * \brief
  * Parse an IPv4 or IPv6 address string.
  *
  * \details
Index: main/netsock2.c
===================================================================
--- main/netsock2.c	(revision 280705)
+++ main/netsock2.c	(working copy)
@@ -118,7 +118,7 @@
 	return ast_str_buffer(str);
 }
 
-int static _ast_sockaddr_parse(char *str, char **host, char **port, int flags)
+int ast_sockaddr_split_hostport(char *str, char **host, char **port, int flags)
 {
 	char *s = str;
 
@@ -187,7 +187,7 @@
 	int	e;
 
 	s = ast_strdupa(str);
-	if (!_ast_sockaddr_parse(s, &host, &port, flags)) {
+	if (!ast_sockaddr_split_hostport(s, &host, &port, flags)) {
 		return 0;
 	}
 
@@ -233,7 +233,7 @@
 	int	e, i, res_cnt;
 
 	s = ast_strdupa(str);
-	if (!_ast_sockaddr_parse(s, &host, &port, flags)) {
+	if (!ast_sockaddr_split_hostport(s, &host, &port, flags)) {
 		return 0;
 	}
 
